from __future__ import annotations

import enum
import typing


class GroupTypeFlags(enum.IntFlag):
    SYSTEM = 0x00000001
    SCOPE_GLOBAL = 0x00000002
    SCOPE_DOMAIN = 0x00000004
    SCOPE_UNIVERSAL = 0x00000008
    APP_BASIC = 0x00000010
    APP_QUERY = 0x00000020
    SECURITY = 0x80000000  # otherwise distribution

    def flags(self) -> list[GroupTypeFlags]:
        # ignore "uncovered" bits for now
        value = self.value
        members = []
        for member in GroupTypeFlags:
            member_value = member.value
            if member_value and member_value & value == member_value:
                members.append(member)
        return members


def parse(value: str) -> str:
    members = GroupTypeFlags(int(value)).flags()
    return ", ".join(typing.cast(str, member.name) for member in members)
